# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.category_info import CategoryInfo  # noqa: F401,E501
from kps_api.models.data_ifc_endpoint import DataIfcEndpoint  # noqa: F401,E501
from kps_api.models.helm_app_metadata import HelmAppMetadata  # noqa: F401,E501


class Application(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_ifc_endpoints': 'list[DataIfcEndpoint]',
        'description': 'str',
        'edge_ids': 'list[str]',
        'edge_selectors': 'list[CategoryInfo]',
        'exclude_edge_ids': 'list[str]',
        'helm_metadata': 'HelmAppMetadata',
        'id': 'str',
        'name': 'str',
        'only_pre_pull_on_update': 'bool',
        'origin_selectors': 'list[CategoryInfo]',
        'packaging_type': 'str',
        'project_id': 'str',
        'state': 'str',
        'user_id': 'str',
        'yaml_data': 'str'
    }

    attribute_map = {
        'data_ifc_endpoints': 'dataIfcEndpoints',
        'description': 'description',
        'edge_ids': 'edgeIds',
        'edge_selectors': 'edgeSelectors',
        'exclude_edge_ids': 'excludeEdgeIds',
        'helm_metadata': 'helmMetadata',
        'id': 'id',
        'name': 'name',
        'only_pre_pull_on_update': 'onlyPrePullOnUpdate',
        'origin_selectors': 'originSelectors',
        'packaging_type': 'packagingType',
        'project_id': 'projectId',
        'state': 'state',
        'user_id': 'userId',
        'yaml_data': 'yamlData'
    }

    def __init__(self, data_ifc_endpoints=None, description=None, edge_ids=None, edge_selectors=None, exclude_edge_ids=None, helm_metadata=None, id=None, name=None, only_pre_pull_on_update=None, origin_selectors=None, packaging_type=None, project_id=None, state=None, user_id=None, yaml_data=None):  # noqa: E501
        """Application - a model defined in Swagger"""  # noqa: E501
        self._data_ifc_endpoints = None
        self._description = None
        self._edge_ids = None
        self._edge_selectors = None
        self._exclude_edge_ids = None
        self._helm_metadata = None
        self._id = None
        self._name = None
        self._only_pre_pull_on_update = None
        self._origin_selectors = None
        self._packaging_type = None
        self._project_id = None
        self._state = None
        self._user_id = None
        self._yaml_data = None
        self.discriminator = None
        if data_ifc_endpoints is not None:
            self.data_ifc_endpoints = data_ifc_endpoints
        if description is not None:
            self.description = description
        if edge_ids is not None:
            self.edge_ids = edge_ids
        if edge_selectors is not None:
            self.edge_selectors = edge_selectors
        if exclude_edge_ids is not None:
            self.exclude_edge_ids = exclude_edge_ids
        if helm_metadata is not None:
            self.helm_metadata = helm_metadata
        if id is not None:
            self.id = id
        self.name = name
        if only_pre_pull_on_update is not None:
            self.only_pre_pull_on_update = only_pre_pull_on_update
        if origin_selectors is not None:
            self.origin_selectors = origin_selectors
        if packaging_type is not None:
            self.packaging_type = packaging_type
        self.project_id = project_id
        if state is not None:
            self.state = state
        if user_id is not None:
            self.user_id = user_id
        self.yaml_data = yaml_data

    @property
    def data_ifc_endpoints(self):
        """Gets the data_ifc_endpoints of this Application.  # noqa: E501

        DataIfcEndpoints is a list of endpoints exposed to an application.  # noqa: E501

        :return: The data_ifc_endpoints of this Application.  # noqa: E501
        :rtype: list[DataIfcEndpoint]
        """
        return self._data_ifc_endpoints

    @data_ifc_endpoints.setter
    def data_ifc_endpoints(self, data_ifc_endpoints):
        """Sets the data_ifc_endpoints of this Application.

        DataIfcEndpoints is a list of endpoints exposed to an application.  # noqa: E501

        :param data_ifc_endpoints: The data_ifc_endpoints of this Application.  # noqa: E501
        :type: list[DataIfcEndpoint]
        """

        self._data_ifc_endpoints = data_ifc_endpoints

    @property
    def description(self):
        """Gets the description of this Application.  # noqa: E501

        A description of the application. Maximum length of 200 characters.  # noqa: E501

        :return: The description of this Application.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Application.

        A description of the application. Maximum length of 200 characters.  # noqa: E501

        :param description: The description of this Application.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def edge_ids(self):
        """Gets the edge_ids of this Application.  # noqa: E501

        Edges listed according to ID where the application is deployed. Only relevant if the parent project EdgeSelectorType value is set to Explicit.  # noqa: E501

        :return: The edge_ids of this Application.  # noqa: E501
        :rtype: list[str]
        """
        return self._edge_ids

    @edge_ids.setter
    def edge_ids(self, edge_ids):
        """Sets the edge_ids of this Application.

        Edges listed according to ID where the application is deployed. Only relevant if the parent project EdgeSelectorType value is set to Explicit.  # noqa: E501

        :param edge_ids: The edge_ids of this Application.  # noqa: E501
        :type: list[str]
        """

        self._edge_ids = edge_ids

    @property
    def edge_selectors(self):
        """Gets the edge_selectors of this Application.  # noqa: E501

        Select edges according to CategoryInfo. Only relevant if the parent project EdgeSelectorType value is set to Category.  # noqa: E501

        :return: The edge_selectors of this Application.  # noqa: E501
        :rtype: list[CategoryInfo]
        """
        return self._edge_selectors

    @edge_selectors.setter
    def edge_selectors(self, edge_selectors):
        """Sets the edge_selectors of this Application.

        Select edges according to CategoryInfo. Only relevant if the parent project EdgeSelectorType value is set to Category.  # noqa: E501

        :param edge_selectors: The edge_selectors of this Application.  # noqa: E501
        :type: list[CategoryInfo]
        """

        self._edge_selectors = edge_selectors

    @property
    def exclude_edge_ids(self):
        """Gets the exclude_edge_ids of this Application.  # noqa: E501

        Edges to be excluded from the application deployment.  # noqa: E501

        :return: The exclude_edge_ids of this Application.  # noqa: E501
        :rtype: list[str]
        """
        return self._exclude_edge_ids

    @exclude_edge_ids.setter
    def exclude_edge_ids(self, exclude_edge_ids):
        """Sets the exclude_edge_ids of this Application.

        Edges to be excluded from the application deployment.  # noqa: E501

        :param exclude_edge_ids: The exclude_edge_ids of this Application.  # noqa: E501
        :type: list[str]
        """

        self._exclude_edge_ids = exclude_edge_ids

    @property
    def helm_metadata(self):
        """Gets the helm_metadata of this Application.  # noqa: E501


        :return: The helm_metadata of this Application.  # noqa: E501
        :rtype: HelmAppMetadata
        """
        return self._helm_metadata

    @helm_metadata.setter
    def helm_metadata(self, helm_metadata):
        """Sets the helm_metadata of this Application.


        :param helm_metadata: The helm_metadata of this Application.  # noqa: E501
        :type: HelmAppMetadata
        """

        self._helm_metadata = helm_metadata

    @property
    def id(self):
        """Gets the id of this Application.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Application.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this Application.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Application.  # noqa: E501

        The application name. Maximum length of 200 characters.  # noqa: E501

        :return: The name of this Application.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Application.

        The application name. Maximum length of 200 characters.  # noqa: E501

        :param name: The name of this Application.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def only_pre_pull_on_update(self):
        """Gets the only_pre_pull_on_update of this Application.  # noqa: E501

        Only pre-pull images on service domains w/o doing an actual update. Service domain which have not yet deployed the app will deploy application like usual. Update will commence once this flag is unset.  # noqa: E501

        :return: The only_pre_pull_on_update of this Application.  # noqa: E501
        :rtype: bool
        """
        return self._only_pre_pull_on_update

    @only_pre_pull_on_update.setter
    def only_pre_pull_on_update(self, only_pre_pull_on_update):
        """Sets the only_pre_pull_on_update of this Application.

        Only pre-pull images on service domains w/o doing an actual update. Service domain which have not yet deployed the app will deploy application like usual. Update will commence once this flag is unset.  # noqa: E501

        :param only_pre_pull_on_update: The only_pre_pull_on_update of this Application.  # noqa: E501
        :type: bool
        """

        self._only_pre_pull_on_update = only_pre_pull_on_update

    @property
    def origin_selectors(self):
        """Gets the origin_selectors of this Application.  # noqa: E501

        OriginSelectors is the list of CategoryInfo used as criteria to feed data into applications.  # noqa: E501

        :return: The origin_selectors of this Application.  # noqa: E501
        :rtype: list[CategoryInfo]
        """
        return self._origin_selectors

    @origin_selectors.setter
    def origin_selectors(self, origin_selectors):
        """Sets the origin_selectors of this Application.

        OriginSelectors is the list of CategoryInfo used as criteria to feed data into applications.  # noqa: E501

        :param origin_selectors: The origin_selectors of this Application.  # noqa: E501
        :type: list[CategoryInfo]
        """

        self._origin_selectors = origin_selectors

    @property
    def packaging_type(self):
        """Gets the packaging_type of this Application.  # noqa: E501

        PackagingType vanilla or helm, nil = vanilla  # noqa: E501

        :return: The packaging_type of this Application.  # noqa: E501
        :rtype: str
        """
        return self._packaging_type

    @packaging_type.setter
    def packaging_type(self, packaging_type):
        """Sets the packaging_type of this Application.

        PackagingType vanilla or helm, nil = vanilla  # noqa: E501

        :param packaging_type: The packaging_type of this Application.  # noqa: E501
        :type: str
        """

        self._packaging_type = packaging_type

    @property
    def project_id(self):
        """Gets the project_id of this Application.  # noqa: E501

        Parent project ID. Not required (to maintain backward compatibility).  # noqa: E501

        :return: The project_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this Application.

        Parent project ID. Not required (to maintain backward compatibility).  # noqa: E501

        :param project_id: The project_id of this Application.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def state(self):
        """Gets the state of this Application.  # noqa: E501

        State of this entity  # noqa: E501

        :return: The state of this Application.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Application.

        State of this entity  # noqa: E501

        :param state: The state of this Application.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def user_id(self):
        """Gets the user_id of this Application.  # noqa: E501

        Last modified user ID. Only required by edge for privilege check.  # noqa: E501

        :return: The user_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Application.

        Last modified user ID. Only required by edge for privilege check.  # noqa: E501

        :param user_id: The user_id of this Application.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def yaml_data(self):
        """Gets the yaml_data of this Application.  # noqa: E501

        The YAML content for the application.  # noqa: E501

        :return: The yaml_data of this Application.  # noqa: E501
        :rtype: str
        """
        return self._yaml_data

    @yaml_data.setter
    def yaml_data(self, yaml_data):
        """Sets the yaml_data of this Application.

        The YAML content for the application.  # noqa: E501

        :param yaml_data: The yaml_data of this Application.  # noqa: E501
        :type: str
        """
        if yaml_data is None:
            raise ValueError("Invalid value for `yaml_data`, must not be `None`")  # noqa: E501

        self._yaml_data = yaml_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Application, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Application):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.cloud_profile_info import CloudProfileInfo  # noqa: F401,E501
from kps_api.models.container_registry_info import ContainerRegistryInfo  # noqa: F401,E501


class ContainerRegistryV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_profile_info': 'CloudProfileInfo',
        'container_registry_info': 'ContainerRegistryInfo',
        'description': 'str',
        'id': 'str',
        'name': 'str',
        'server': 'str',
        'type': 'str'
    }

    attribute_map = {
        'cloud_profile_info': 'CloudProfileInfo',
        'container_registry_info': 'ContainerRegistryInfo',
        'description': 'description',
        'id': 'id',
        'name': 'name',
        'server': 'server',
        'type': 'type'
    }

    def __init__(self, cloud_profile_info=None, container_registry_info=None, description=None, id=None, name=None, server=None, type=None):  # noqa: E501
        """ContainerRegistryV2 - a model defined in Swagger"""  # noqa: E501
        self._cloud_profile_info = None
        self._container_registry_info = None
        self._description = None
        self._id = None
        self._name = None
        self._server = None
        self._type = None
        self.discriminator = None
        if cloud_profile_info is not None:
            self.cloud_profile_info = cloud_profile_info
        if container_registry_info is not None:
            self.container_registry_info = container_registry_info
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        self.name = name
        self.server = server
        self.type = type

    @property
    def cloud_profile_info(self):
        """Gets the cloud_profile_info of this ContainerRegistryV2.  # noqa: E501


        :return: The cloud_profile_info of this ContainerRegistryV2.  # noqa: E501
        :rtype: CloudProfileInfo
        """
        return self._cloud_profile_info

    @cloud_profile_info.setter
    def cloud_profile_info(self, cloud_profile_info):
        """Sets the cloud_profile_info of this ContainerRegistryV2.


        :param cloud_profile_info: The cloud_profile_info of this ContainerRegistryV2.  # noqa: E501
        :type: CloudProfileInfo
        """

        self._cloud_profile_info = cloud_profile_info

    @property
    def container_registry_info(self):
        """Gets the container_registry_info of this ContainerRegistryV2.  # noqa: E501


        :return: The container_registry_info of this ContainerRegistryV2.  # noqa: E501
        :rtype: ContainerRegistryInfo
        """
        return self._container_registry_info

    @container_registry_info.setter
    def container_registry_info(self, container_registry_info):
        """Sets the container_registry_info of this ContainerRegistryV2.


        :param container_registry_info: The container_registry_info of this ContainerRegistryV2.  # noqa: E501
        :type: ContainerRegistryInfo
        """

        self._container_registry_info = container_registry_info

    @property
    def description(self):
        """Gets the description of this ContainerRegistryV2.  # noqa: E501

        Description for the container registry.  # noqa: E501

        :return: The description of this ContainerRegistryV2.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ContainerRegistryV2.

        Description for the container registry.  # noqa: E501

        :param description: The description of this ContainerRegistryV2.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this ContainerRegistryV2.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this ContainerRegistryV2.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ContainerRegistryV2.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this ContainerRegistryV2.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ContainerRegistryV2.  # noqa: E501

        Name for the container registry.  # noqa: E501

        :return: The name of this ContainerRegistryV2.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ContainerRegistryV2.

        Name for the container registry.  # noqa: E501

        :param name: The name of this ContainerRegistryV2.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def server(self):
        """Gets the server of this ContainerRegistryV2.  # noqa: E501

        Container registry server URL. For example, an Amazon AWS Elastic Container Registry (ECR) URL might be: https://aws_account_id.dkr.ecr.region.amazonaws.com  # noqa: E501

        :return: The server of this ContainerRegistryV2.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this ContainerRegistryV2.

        Container registry server URL. For example, an Amazon AWS Elastic Container Registry (ECR) URL might be: https://aws_account_id.dkr.ecr.region.amazonaws.com  # noqa: E501

        :param server: The server of this ContainerRegistryV2.  # noqa: E501
        :type: str
        """
        if server is None:
            raise ValueError("Invalid value for `server`, must not be `None`")  # noqa: E501

        self._server = server

    @property
    def type(self):
        """Gets the type of this ContainerRegistryV2.  # noqa: E501

        Container registry type.  # noqa: E501

        :return: The type of this ContainerRegistryV2.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ContainerRegistryV2.

        Container registry type.  # noqa: E501

        :param type: The type of this ContainerRegistryV2.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["AWS", "GCP", "Azure", "ContainerRegistry"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContainerRegistryV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContainerRegistryV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.ai_inferencing_service_profile import AIInferencingServiceProfile  # noqa: F401,E501


class ServiceDomainProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ai_inferencing_service': 'AIInferencingServiceProfile',
        'enable_ssh': 'bool',
        'ingress_type': 'str',
        'privileged': 'bool'
    }

    attribute_map = {
        'ai_inferencing_service': 'AIInferencingService',
        'enable_ssh': 'enableSSH',
        'ingress_type': 'ingressType',
        'privileged': 'privileged'
    }

    def __init__(self, ai_inferencing_service=None, enable_ssh=None, ingress_type=None, privileged=None):  # noqa: E501
        """ServiceDomainProfile - a model defined in Swagger"""  # noqa: E501
        self._ai_inferencing_service = None
        self._enable_ssh = None
        self._ingress_type = None
        self._privileged = None
        self.discriminator = None
        if ai_inferencing_service is not None:
            self.ai_inferencing_service = ai_inferencing_service
        if enable_ssh is not None:
            self.enable_ssh = enable_ssh
        if ingress_type is not None:
            self.ingress_type = ingress_type
        if privileged is not None:
            self.privileged = privileged

    @property
    def ai_inferencing_service(self):
        """Gets the ai_inferencing_service of this ServiceDomainProfile.  # noqa: E501


        :return: The ai_inferencing_service of this ServiceDomainProfile.  # noqa: E501
        :rtype: AIInferencingServiceProfile
        """
        return self._ai_inferencing_service

    @ai_inferencing_service.setter
    def ai_inferencing_service(self, ai_inferencing_service):
        """Sets the ai_inferencing_service of this ServiceDomainProfile.


        :param ai_inferencing_service: The ai_inferencing_service of this ServiceDomainProfile.  # noqa: E501
        :type: AIInferencingServiceProfile
        """

        self._ai_inferencing_service = ai_inferencing_service

    @property
    def enable_ssh(self):
        """Gets the enable_ssh of this ServiceDomainProfile.  # noqa: E501


        :return: The enable_ssh of this ServiceDomainProfile.  # noqa: E501
        :rtype: bool
        """
        return self._enable_ssh

    @enable_ssh.setter
    def enable_ssh(self, enable_ssh):
        """Sets the enable_ssh of this ServiceDomainProfile.


        :param enable_ssh: The enable_ssh of this ServiceDomainProfile.  # noqa: E501
        :type: bool
        """

        self._enable_ssh = enable_ssh

    @property
    def ingress_type(self):
        """Gets the ingress_type of this ServiceDomainProfile.  # noqa: E501


        :return: The ingress_type of this ServiceDomainProfile.  # noqa: E501
        :rtype: str
        """
        return self._ingress_type

    @ingress_type.setter
    def ingress_type(self, ingress_type):
        """Sets the ingress_type of this ServiceDomainProfile.


        :param ingress_type: The ingress_type of this ServiceDomainProfile.  # noqa: E501
        :type: str
        """
        allowed_values = ["Traefik", "NGINX"]  # noqa: E501
        if ingress_type not in allowed_values:
            raise ValueError(
                "Invalid value for `ingress_type` ({0}), must be one of {1}"  # noqa: E501
                .format(ingress_type, allowed_values)
            )

        self._ingress_type = ingress_type

    @property
    def privileged(self):
        """Gets the privileged of this ServiceDomainProfile.  # noqa: E501


        :return: The privileged of this ServiceDomainProfile.  # noqa: E501
        :rtype: bool
        """
        return self._privileged

    @privileged.setter
    def privileged(self, privileged):
        """Sets the privileged of this ServiceDomainProfile.


        :param privileged: The privileged of this ServiceDomainProfile.  # noqa: E501
        :type: bool
        """

        self._privileged = privileged

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceDomainProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceDomainProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.protocol_traffic import ProtocolTraffic  # noqa: F401,E501


class EdgeData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'is_mtls': 'str',
        'response_time': 'str',
        'source': 'str',
        'target': 'str',
        'traffic': 'ProtocolTraffic'
    }

    attribute_map = {
        'id': 'id',
        'is_mtls': 'isMTLS',
        'response_time': 'responseTime',
        'source': 'source',
        'target': 'target',
        'traffic': 'traffic'
    }

    def __init__(self, id=None, is_mtls=None, response_time=None, source=None, target=None, traffic=None):  # noqa: E501
        """EdgeData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._is_mtls = None
        self._response_time = None
        self._source = None
        self._target = None
        self._traffic = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if is_mtls is not None:
            self.is_mtls = is_mtls
        if response_time is not None:
            self.response_time = response_time
        if source is not None:
            self.source = source
        if target is not None:
            self.target = target
        if traffic is not None:
            self.traffic = traffic

    @property
    def id(self):
        """Gets the id of this EdgeData.  # noqa: E501

        Cytoscape Fields  # noqa: E501

        :return: The id of this EdgeData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EdgeData.

        Cytoscape Fields  # noqa: E501

        :param id: The id of this EdgeData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_mtls(self):
        """Gets the is_mtls of this EdgeData.  # noqa: E501


        :return: The is_mtls of this EdgeData.  # noqa: E501
        :rtype: str
        """
        return self._is_mtls

    @is_mtls.setter
    def is_mtls(self, is_mtls):
        """Sets the is_mtls of this EdgeData.


        :param is_mtls: The is_mtls of this EdgeData.  # noqa: E501
        :type: str
        """

        self._is_mtls = is_mtls

    @property
    def response_time(self):
        """Gets the response_time of this EdgeData.  # noqa: E501


        :return: The response_time of this EdgeData.  # noqa: E501
        :rtype: str
        """
        return self._response_time

    @response_time.setter
    def response_time(self, response_time):
        """Sets the response_time of this EdgeData.


        :param response_time: The response_time of this EdgeData.  # noqa: E501
        :type: str
        """

        self._response_time = response_time

    @property
    def source(self):
        """Gets the source of this EdgeData.  # noqa: E501


        :return: The source of this EdgeData.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this EdgeData.


        :param source: The source of this EdgeData.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def target(self):
        """Gets the target of this EdgeData.  # noqa: E501


        :return: The target of this EdgeData.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this EdgeData.


        :param target: The target of this EdgeData.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def traffic(self):
        """Gets the traffic of this EdgeData.  # noqa: E501


        :return: The traffic of this EdgeData.  # noqa: E501
        :rtype: ProtocolTraffic
        """
        return self._traffic

    @traffic.setter
    def traffic(self, traffic):
        """Sets the traffic of this EdgeData.


        :param traffic: The traffic of this EdgeData.  # noqa: E501
        :type: ProtocolTraffic
        """

        self._traffic = traffic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class UserApiTokenCreated(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'tenant_id': 'str',
        'token': 'str',
        'user_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'tenant_id': 'tenantId',
        'token': 'token',
        'user_id': 'userId'
    }

    def __init__(self, id=None, tenant_id=None, token=None, user_id=None):  # noqa: E501
        """UserApiTokenCreated - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._tenant_id = None
        self._token = None
        self._user_id = None
        self.discriminator = None
        self.id = id
        self.tenant_id = tenant_id
        self.token = token
        self.user_id = user_id

    @property
    def id(self):
        """Gets the id of this UserApiTokenCreated.  # noqa: E501

        ID of the user API token  # noqa: E501

        :return: The id of this UserApiTokenCreated.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserApiTokenCreated.

        ID of the user API token  # noqa: E501

        :param id: The id of this UserApiTokenCreated.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this UserApiTokenCreated.  # noqa: E501

        Tenant ID  # noqa: E501

        :return: The tenant_id of this UserApiTokenCreated.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this UserApiTokenCreated.

        Tenant ID  # noqa: E501

        :param tenant_id: The tenant_id of this UserApiTokenCreated.  # noqa: E501
        :type: str
        """
        if tenant_id is None:
            raise ValueError("Invalid value for `tenant_id`, must not be `None`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def token(self):
        """Gets the token of this UserApiTokenCreated.  # noqa: E501

        JWT token. User must save away this token. Karbon Platform Services does not store this token and it will not be returned by any subsequent API calls.  # noqa: E501

        :return: The token of this UserApiTokenCreated.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UserApiTokenCreated.

        JWT token. User must save away this token. Karbon Platform Services does not store this token and it will not be returned by any subsequent API calls.  # noqa: E501

        :param token: The token of this UserApiTokenCreated.  # noqa: E501
        :type: str
        """
        if token is None:
            raise ValueError("Invalid value for `token`, must not be `None`")  # noqa: E501

        self._token = token

    @property
    def user_id(self):
        """Gets the user_id of this UserApiTokenCreated.  # noqa: E501

        User ID  # noqa: E501

        :return: The user_id of this UserApiTokenCreated.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserApiTokenCreated.

        User ID  # noqa: E501

        :param user_id: The user_id of this UserApiTokenCreated.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserApiTokenCreated, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserApiTokenCreated):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.category_info import CategoryInfo  # noqa: F401,E501
from kps_api.models.connector_parameters_values import ConnectorParametersValues  # noqa: F401,E501
from kps_api.models.connector_stream_direction import ConnectorStreamDirection  # noqa: F401,E501


class ConnectorStream(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'connector_instance_id': 'str',
        'description': 'str',
        'direction': 'ConnectorStreamDirection',
        'exclude_service_domain_ids': 'list[str]',
        'id': 'str',
        'labels': 'list[CategoryInfo]',
        'name': 'str',
        'service_domain_ids': 'list[str]',
        'service_domain_selectors': 'list[CategoryInfo]',
        'stream': 'ConnectorParametersValues'
    }

    attribute_map = {
        'connector_instance_id': 'connectorInstanceID',
        'description': 'description',
        'direction': 'direction',
        'exclude_service_domain_ids': 'excludeServiceDomainIds',
        'id': 'id',
        'labels': 'labels',
        'name': 'name',
        'service_domain_ids': 'serviceDomainIds',
        'service_domain_selectors': 'serviceDomainSelectors',
        'stream': 'stream'
    }

    def __init__(self, connector_instance_id=None, description=None, direction=None, exclude_service_domain_ids=None, id=None, labels=None, name=None, service_domain_ids=None, service_domain_selectors=None, stream=None):  # noqa: E501
        """ConnectorStream - a model defined in Swagger"""  # noqa: E501
        self._connector_instance_id = None
        self._description = None
        self._direction = None
        self._exclude_service_domain_ids = None
        self._id = None
        self._labels = None
        self._name = None
        self._service_domain_ids = None
        self._service_domain_selectors = None
        self._stream = None
        self.discriminator = None
        self.connector_instance_id = connector_instance_id
        if description is not None:
            self.description = description
        self.direction = direction
        if exclude_service_domain_ids is not None:
            self.exclude_service_domain_ids = exclude_service_domain_ids
        if id is not None:
            self.id = id
        if labels is not None:
            self.labels = labels
        self.name = name
        if service_domain_ids is not None:
            self.service_domain_ids = service_domain_ids
        if service_domain_selectors is not None:
            self.service_domain_selectors = service_domain_selectors
        self.stream = stream

    @property
    def connector_instance_id(self):
        """Gets the connector_instance_id of this ConnectorStream.  # noqa: E501


        :return: The connector_instance_id of this ConnectorStream.  # noqa: E501
        :rtype: str
        """
        return self._connector_instance_id

    @connector_instance_id.setter
    def connector_instance_id(self, connector_instance_id):
        """Sets the connector_instance_id of this ConnectorStream.


        :param connector_instance_id: The connector_instance_id of this ConnectorStream.  # noqa: E501
        :type: str
        """
        if connector_instance_id is None:
            raise ValueError("Invalid value for `connector_instance_id`, must not be `None`")  # noqa: E501

        self._connector_instance_id = connector_instance_id

    @property
    def description(self):
        """Gets the description of this ConnectorStream.  # noqa: E501


        :return: The description of this ConnectorStream.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ConnectorStream.


        :param description: The description of this ConnectorStream.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def direction(self):
        """Gets the direction of this ConnectorStream.  # noqa: E501


        :return: The direction of this ConnectorStream.  # noqa: E501
        :rtype: ConnectorStreamDirection
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this ConnectorStream.


        :param direction: The direction of this ConnectorStream.  # noqa: E501
        :type: ConnectorStreamDirection
        """
        if direction is None:
            raise ValueError("Invalid value for `direction`, must not be `None`")  # noqa: E501

        self._direction = direction

    @property
    def exclude_service_domain_ids(self):
        """Gets the exclude_service_domain_ids of this ConnectorStream.  # noqa: E501

        Service domains to be excluded from the connector config deployment.  # noqa: E501

        :return: The exclude_service_domain_ids of this ConnectorStream.  # noqa: E501
        :rtype: list[str]
        """
        return self._exclude_service_domain_ids

    @exclude_service_domain_ids.setter
    def exclude_service_domain_ids(self, exclude_service_domain_ids):
        """Sets the exclude_service_domain_ids of this ConnectorStream.

        Service domains to be excluded from the connector config deployment.  # noqa: E501

        :param exclude_service_domain_ids: The exclude_service_domain_ids of this ConnectorStream.  # noqa: E501
        :type: list[str]
        """

        self._exclude_service_domain_ids = exclude_service_domain_ids

    @property
    def id(self):
        """Gets the id of this ConnectorStream.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this ConnectorStream.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConnectorStream.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this ConnectorStream.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def labels(self):
        """Gets the labels of this ConnectorStream.  # noqa: E501

        A list of Category labels for this connector config. \"SOURCE\" connector streams should have at least 1 label. \"SINK\" should not have any labels.  # noqa: E501

        :return: The labels of this ConnectorStream.  # noqa: E501
        :rtype: list[CategoryInfo]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this ConnectorStream.

        A list of Category labels for this connector config. \"SOURCE\" connector streams should have at least 1 label. \"SINK\" should not have any labels.  # noqa: E501

        :param labels: The labels of this ConnectorStream.  # noqa: E501
        :type: list[CategoryInfo]
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this ConnectorStream.  # noqa: E501


        :return: The name of this ConnectorStream.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConnectorStream.


        :param name: The name of this ConnectorStream.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def service_domain_ids(self):
        """Gets the service_domain_ids of this ConnectorStream.  # noqa: E501

        Service domains listed according to ID where the connector config is deployed. Only relevant if the parent project EdgeSelectorType value is set to Explicit.  # noqa: E501

        :return: The service_domain_ids of this ConnectorStream.  # noqa: E501
        :rtype: list[str]
        """
        return self._service_domain_ids

    @service_domain_ids.setter
    def service_domain_ids(self, service_domain_ids):
        """Sets the service_domain_ids of this ConnectorStream.

        Service domains listed according to ID where the connector config is deployed. Only relevant if the parent project EdgeSelectorType value is set to Explicit.  # noqa: E501

        :param service_domain_ids: The service_domain_ids of this ConnectorStream.  # noqa: E501
        :type: list[str]
        """

        self._service_domain_ids = service_domain_ids

    @property
    def service_domain_selectors(self):
        """Gets the service_domain_selectors of this ConnectorStream.  # noqa: E501

        Select service domains according to CategoryInfo. Only relevant if the parent project EdgeSelectorType value is set to Category.  # noqa: E501

        :return: The service_domain_selectors of this ConnectorStream.  # noqa: E501
        :rtype: list[CategoryInfo]
        """
        return self._service_domain_selectors

    @service_domain_selectors.setter
    def service_domain_selectors(self, service_domain_selectors):
        """Sets the service_domain_selectors of this ConnectorStream.

        Select service domains according to CategoryInfo. Only relevant if the parent project EdgeSelectorType value is set to Category.  # noqa: E501

        :param service_domain_selectors: The service_domain_selectors of this ConnectorStream.  # noqa: E501
        :type: list[CategoryInfo]
        """

        self._service_domain_selectors = service_domain_selectors

    @property
    def stream(self):
        """Gets the stream of this ConnectorStream.  # noqa: E501


        :return: The stream of this ConnectorStream.  # noqa: E501
        :rtype: ConnectorParametersValues
        """
        return self._stream

    @stream.setter
    def stream(self, stream):
        """Sets the stream of this ConnectorStream.


        :param stream: The stream of this ConnectorStream.  # noqa: E501
        :type: ConnectorParametersValues
        """
        if stream is None:
            raise ValueError("Invalid value for `stream`, must not be `None`")  # noqa: E501

        self._stream = stream

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConnectorStream, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectorStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class KubernetesCluster(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chart_version': 'str',
        'connected': 'bool',
        'description': 'str',
        'id': 'str',
        'is_service_domain': 'bool',
        'kube_version': 'str',
        'name': 'str',
        'onboarded': 'bool'
    }

    attribute_map = {
        'chart_version': 'chartVersion',
        'connected': 'connected',
        'description': 'description',
        'id': 'id',
        'is_service_domain': 'isServiceDomain',
        'kube_version': 'kubeVersion',
        'name': 'name',
        'onboarded': 'onboarded'
    }

    def __init__(self, chart_version=None, connected=None, description=None, id=None, is_service_domain=None, kube_version=None, name=None, onboarded=None):  # noqa: E501
        """KubernetesCluster - a model defined in Swagger"""  # noqa: E501
        self._chart_version = None
        self._connected = None
        self._description = None
        self._id = None
        self._is_service_domain = None
        self._kube_version = None
        self._name = None
        self._onboarded = None
        self.discriminator = None
        if chart_version is not None:
            self.chart_version = chart_version
        if connected is not None:
            self.connected = connected
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if is_service_domain is not None:
            self.is_service_domain = is_service_domain
        if kube_version is not None:
            self.kube_version = kube_version
        self.name = name
        if onboarded is not None:
            self.onboarded = onboarded

    @property
    def chart_version(self):
        """Gets the chart_version of this KubernetesCluster.  # noqa: E501

        Chart version of the current cluster  # noqa: E501

        :return: The chart_version of this KubernetesCluster.  # noqa: E501
        :rtype: str
        """
        return self._chart_version

    @chart_version.setter
    def chart_version(self, chart_version):
        """Sets the chart_version of this KubernetesCluster.

        Chart version of the current cluster  # noqa: E501

        :param chart_version: The chart_version of this KubernetesCluster.  # noqa: E501
        :type: str
        """

        self._chart_version = chart_version

    @property
    def connected(self):
        """Gets the connected of this KubernetesCluster.  # noqa: E501

        Connecting status of the current cluster Either true or false  # noqa: E501

        :return: The connected of this KubernetesCluster.  # noqa: E501
        :rtype: bool
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """Sets the connected of this KubernetesCluster.

        Connecting status of the current cluster Either true or false  # noqa: E501

        :param connected: The connected of this KubernetesCluster.  # noqa: E501
        :type: bool
        """

        self._connected = connected

    @property
    def description(self):
        """Gets the description of this KubernetesCluster.  # noqa: E501

        KubernetesCluster description  # noqa: E501

        :return: The description of this KubernetesCluster.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this KubernetesCluster.

        KubernetesCluster description  # noqa: E501

        :param description: The description of this KubernetesCluster.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this KubernetesCluster.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this KubernetesCluster.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this KubernetesCluster.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this KubernetesCluster.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_service_domain(self):
        """Gets the is_service_domain of this KubernetesCluster.  # noqa: E501

        Whether Kubernetes cluster has complete service domain PaaS stack deployedl  # noqa: E501

        :return: The is_service_domain of this KubernetesCluster.  # noqa: E501
        :rtype: bool
        """
        return self._is_service_domain

    @is_service_domain.setter
    def is_service_domain(self, is_service_domain):
        """Sets the is_service_domain of this KubernetesCluster.

        Whether Kubernetes cluster has complete service domain PaaS stack deployedl  # noqa: E501

        :param is_service_domain: The is_service_domain of this KubernetesCluster.  # noqa: E501
        :type: bool
        """

        self._is_service_domain = is_service_domain

    @property
    def kube_version(self):
        """Gets the kube_version of this KubernetesCluster.  # noqa: E501

        Kubernetes version of the current cluster  # noqa: E501

        :return: The kube_version of this KubernetesCluster.  # noqa: E501
        :rtype: str
        """
        return self._kube_version

    @kube_version.setter
    def kube_version(self, kube_version):
        """Sets the kube_version of this KubernetesCluster.

        Kubernetes version of the current cluster  # noqa: E501

        :param kube_version: The kube_version of this KubernetesCluster.  # noqa: E501
        :type: str
        """

        self._kube_version = kube_version

    @property
    def name(self):
        """Gets the name of this KubernetesCluster.  # noqa: E501

        Name of the Kubernetes Cluster. Maximum length of 200 characters.  # noqa: E501

        :return: The name of this KubernetesCluster.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KubernetesCluster.

        Name of the Kubernetes Cluster. Maximum length of 200 characters.  # noqa: E501

        :param name: The name of this KubernetesCluster.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def onboarded(self):
        """Gets the onboarded of this KubernetesCluster.  # noqa: E501

        Onboarded status of the current cluster Either true or false  # noqa: E501

        :return: The onboarded of this KubernetesCluster.  # noqa: E501
        :rtype: bool
        """
        return self._onboarded

    @onboarded.setter
    def onboarded(self, onboarded):
        """Sets the onboarded of this KubernetesCluster.

        Onboarded status of the current cluster Either true or false  # noqa: E501

        :param onboarded: The onboarded of this KubernetesCluster.  # noqa: E501
        :type: bool
        """

        self._onboarded = onboarded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(KubernetesCluster, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KubernetesCluster):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.fields_v1 import FieldsV1  # noqa: F401,E501
from kps_api.models.managed_fields_operation_type import ManagedFieldsOperationType  # noqa: F401,E501
from kps_api.models.time import Time  # noqa: F401,E501


class ManagedFieldsEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'fields_type': 'str',
        'fields_v1': 'FieldsV1',
        'manager': 'str',
        'operation': 'ManagedFieldsOperationType',
        'time': 'Time'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'fields_type': 'fieldsType',
        'fields_v1': 'fieldsV1',
        'manager': 'manager',
        'operation': 'operation',
        'time': 'time'
    }

    def __init__(self, api_version=None, fields_type=None, fields_v1=None, manager=None, operation=None, time=None):  # noqa: E501
        """ManagedFieldsEntry - a model defined in Swagger"""  # noqa: E501
        self._api_version = None
        self._fields_type = None
        self._fields_v1 = None
        self._manager = None
        self._operation = None
        self._time = None
        self.discriminator = None
        if api_version is not None:
            self.api_version = api_version
        if fields_type is not None:
            self.fields_type = fields_type
        if fields_v1 is not None:
            self.fields_v1 = fields_v1
        if manager is not None:
            self.manager = manager
        if operation is not None:
            self.operation = operation
        if time is not None:
            self.time = time

    @property
    def api_version(self):
        """Gets the api_version of this ManagedFieldsEntry.  # noqa: E501

        APIVersion defines the version of this resource that this field set applies to. The format is \"group/version\" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted.  # noqa: E501

        :return: The api_version of this ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this ManagedFieldsEntry.

        APIVersion defines the version of this resource that this field set applies to. The format is \"group/version\" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted.  # noqa: E501

        :param api_version: The api_version of this ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def fields_type(self):
        """Gets the fields_type of this ManagedFieldsEntry.  # noqa: E501

        FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: \"FieldsV1\"  # noqa: E501

        :return: The fields_type of this ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._fields_type

    @fields_type.setter
    def fields_type(self, fields_type):
        """Sets the fields_type of this ManagedFieldsEntry.

        FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: \"FieldsV1\"  # noqa: E501

        :param fields_type: The fields_type of this ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._fields_type = fields_type

    @property
    def fields_v1(self):
        """Gets the fields_v1 of this ManagedFieldsEntry.  # noqa: E501


        :return: The fields_v1 of this ManagedFieldsEntry.  # noqa: E501
        :rtype: FieldsV1
        """
        return self._fields_v1

    @fields_v1.setter
    def fields_v1(self, fields_v1):
        """Sets the fields_v1 of this ManagedFieldsEntry.


        :param fields_v1: The fields_v1 of this ManagedFieldsEntry.  # noqa: E501
        :type: FieldsV1
        """

        self._fields_v1 = fields_v1

    @property
    def manager(self):
        """Gets the manager of this ManagedFieldsEntry.  # noqa: E501

        Manager is an identifier of the workflow managing these fields.  # noqa: E501

        :return: The manager of this ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._manager

    @manager.setter
    def manager(self, manager):
        """Sets the manager of this ManagedFieldsEntry.

        Manager is an identifier of the workflow managing these fields.  # noqa: E501

        :param manager: The manager of this ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._manager = manager

    @property
    def operation(self):
        """Gets the operation of this ManagedFieldsEntry.  # noqa: E501


        :return: The operation of this ManagedFieldsEntry.  # noqa: E501
        :rtype: ManagedFieldsOperationType
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this ManagedFieldsEntry.


        :param operation: The operation of this ManagedFieldsEntry.  # noqa: E501
        :type: ManagedFieldsOperationType
        """

        self._operation = operation

    @property
    def time(self):
        """Gets the time of this ManagedFieldsEntry.  # noqa: E501


        :return: The time of this ManagedFieldsEntry.  # noqa: E501
        :rtype: Time
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ManagedFieldsEntry.


        :param time: The time of this ManagedFieldsEntry.  # noqa: E501
        :type: Time
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ManagedFieldsEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ManagedFieldsEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.ml_model_api import MLModelApi  # noqa: E501
from kps_api.rest import ApiException


class TestMLModelApi(unittest.TestCase):
    """MLModelApi unit test stubs"""

    def setUp(self):
        self.api = api.ml_model_api.MLModelApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_m_l_model_create(self):
        """Test case for m_l_model_create

        Create a machine learning model.  # noqa: E501
        """
        pass

    def test_m_l_model_delete(self):
        """Test case for m_l_model_delete

        Delete a machine learning model  by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_get(self):
        """Test case for m_l_model_get

        Get machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_list(self):
        """Test case for m_l_model_list

        Lists machine learning models.  # noqa: E501
        """
        pass

    def test_m_l_model_update(self):
        """Test case for m_l_model_update

        Update a machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_create(self):
        """Test case for m_l_model_version_create

        Create a new version of the machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_delete(self):
        """Test case for m_l_model_version_delete

        Delete the version of the machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_update(self):
        """Test case for m_l_model_version_update

        Update the version of the machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_url_get(self):
        """Test case for m_l_model_version_url_get

        Get a pre-signed URL for the machine learning model according to its ID and version.  # noqa: E501
        """
        pass

    def test_project_get_ml_models(self):
        """Test case for project_get_ml_models

        Lists project machine learning models by project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.log_api import LogApi  # noqa: E501
from kps_api.rest import ApiException


class TestLogApi(unittest.TestCase):
    """LogApi unit test stubs"""

    def setUp(self):
        self.api = api.log_api.LogApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_application_log_entries_get_v2(self):
        """Test case for application_log_entries_get_v2

        Lists applications log entries specific to an application.  # noqa: E501
        """
        pass

    def test_application_log_entries_list_v2(self):
        """Test case for application_log_entries_list_v2

        Lists application log entries.  # noqa: E501
        """
        pass

    def test_edge_log_entries_get_v2(self):
        """Test case for edge_log_entries_get_v2

        Lists infrastructure log entries for an edge.  # noqa: E501
        """
        pass

    def test_edge_log_entries_list_v2(self):
        """Test case for edge_log_entries_list_v2

        Lists infrastructure log entries for edges.  # noqa: E501
        """
        pass

    def test_log_entries_list_v2(self):
        """Test case for log_entries_list_v2

        Lists log entries.  # noqa: E501
        """
        pass

    def test_log_entry_delete_v2(self):
        """Test case for log_entry_delete_v2

        Delete log entry by ID.  # noqa: E501
        """
        pass

    def test_log_request_download_v2(self):
        """Test case for log_request_download_v2

        Request log download.  # noqa: E501
        """
        pass

    def test_log_request_upload_v2(self):
        """Test case for log_request_upload_v2

        Request log upload.  # noqa: E501
        """
        pass

    def test_log_stream_endpoints(self):
        """Test case for log_stream_endpoints

        Get the endpoints to stream logs for a given container from an edge.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.log_tag import LogTag  # noqa: F401,E501
from kps_api.models.log_upload_status import LogUploadStatus  # noqa: F401,E501


class LogEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'batch_id': 'str',
        'edge_id': 'str',
        'error_message': 'str',
        'id': 'str',
        'location': 'str',
        'status': 'LogUploadStatus',
        'tags': 'list[LogTag]'
    }

    attribute_map = {
        'batch_id': 'batchId',
        'edge_id': 'edgeId',
        'error_message': 'errorMessage',
        'id': 'id',
        'location': 'location',
        'status': 'status',
        'tags': 'tags'
    }

    def __init__(self, batch_id=None, edge_id=None, error_message=None, id=None, location=None, status=None, tags=None):  # noqa: E501
        """LogEntry - a model defined in Swagger"""  # noqa: E501
        self._batch_id = None
        self._edge_id = None
        self._error_message = None
        self._id = None
        self._location = None
        self._status = None
        self._tags = None
        self.discriminator = None
        if batch_id is not None:
            self.batch_id = batch_id
        self.edge_id = edge_id
        if error_message is not None:
            self.error_message = error_message
        if id is not None:
            self.id = id
        if location is not None:
            self.location = location
        if status is not None:
            self.status = status
        if tags is not None:
            self.tags = tags

    @property
    def batch_id(self):
        """Gets the batch_id of this LogEntry.  # noqa: E501

        ID that identifies logs from different edge as the same batch.  # noqa: E501

        :return: The batch_id of this LogEntry.  # noqa: E501
        :rtype: str
        """
        return self._batch_id

    @batch_id.setter
    def batch_id(self, batch_id):
        """Sets the batch_id of this LogEntry.

        ID that identifies logs from different edge as the same batch.  # noqa: E501

        :param batch_id: The batch_id of this LogEntry.  # noqa: E501
        :type: str
        """

        self._batch_id = batch_id

    @property
    def edge_id(self):
        """Gets the edge_id of this LogEntry.  # noqa: E501

        ID of the edge this entity belongs to  # noqa: E501

        :return: The edge_id of this LogEntry.  # noqa: E501
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """Sets the edge_id of this LogEntry.

        ID of the edge this entity belongs to  # noqa: E501

        :param edge_id: The edge_id of this LogEntry.  # noqa: E501
        :type: str
        """
        if edge_id is None:
            raise ValueError("Invalid value for `edge_id`, must not be `None`")  # noqa: E501

        self._edge_id = edge_id

    @property
    def error_message(self):
        """Gets the error_message of this LogEntry.  # noqa: E501

        Error message - optional, should be populated when status == 'FAILED'  # noqa: E501

        :return: The error_message of this LogEntry.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this LogEntry.

        Error message - optional, should be populated when status == 'FAILED'  # noqa: E501

        :param error_message: The error_message of this LogEntry.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def id(self):
        """Gets the id of this LogEntry.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this LogEntry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LogEntry.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this LogEntry.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def location(self):
        """Gets the location of this LogEntry.  # noqa: E501

        Location or object key for the log in the bucket.  # noqa: E501

        :return: The location of this LogEntry.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this LogEntry.

        Location or object key for the log in the bucket.  # noqa: E501

        :param location: The location of this LogEntry.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def status(self):
        """Gets the status of this LogEntry.  # noqa: E501


        :return: The status of this LogEntry.  # noqa: E501
        :rtype: LogUploadStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LogEntry.


        :param status: The status of this LogEntry.  # noqa: E501
        :type: LogUploadStatus
        """

        self._status = status

    @property
    def tags(self):
        """Gets the tags of this LogEntry.  # noqa: E501

        Tags carry the properties of the log  # noqa: E501

        :return: The tags of this LogEntry.  # noqa: E501
        :rtype: list[LogTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this LogEntry.

        Tags carry the properties of the log  # noqa: E501

        :param tags: The tags of this LogEntry.  # noqa: E501
        :type: list[LogTag]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LogEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class HelmAppMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'crds': 'str',
        'metadata': 'str',
        'values': 'str'
    }

    attribute_map = {
        'crds': 'crds',
        'metadata': 'metadata',
        'values': 'values'
    }

    def __init__(self, crds=None, metadata=None, values=None):  # noqa: E501
        """HelmAppMetadata - a model defined in Swagger"""  # noqa: E501
        self._crds = None
        self._metadata = None
        self._values = None
        self.discriminator = None
        if crds is not None:
            self.crds = crds
        self.metadata = metadata
        if values is not None:
            self.values = values

    @property
    def crds(self):
        """Gets the crds of this HelmAppMetadata.  # noqa: E501

        Helm chart CRDs as a string  # noqa: E501

        :return: The crds of this HelmAppMetadata.  # noqa: E501
        :rtype: str
        """
        return self._crds

    @crds.setter
    def crds(self, crds):
        """Sets the crds of this HelmAppMetadata.

        Helm chart CRDs as a string  # noqa: E501

        :param crds: The crds of this HelmAppMetadata.  # noqa: E501
        :type: str
        """

        self._crds = crds

    @property
    def metadata(self):
        """Gets the metadata of this HelmAppMetadata.  # noqa: E501


        :return: The metadata of this HelmAppMetadata.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this HelmAppMetadata.


        :param metadata: The metadata of this HelmAppMetadata.  # noqa: E501
        :type: str
        """
        if metadata is None:
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def values(self):
        """Gets the values of this HelmAppMetadata.  # noqa: E501

        values.yaml as a string  # noqa: E501

        :return: The values of this HelmAppMetadata.  # noqa: E501
        :rtype: str
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this HelmAppMetadata.

        values.yaml as a string  # noqa: E501

        :param values: The values of this HelmAppMetadata.  # noqa: E501
        :type: str
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HelmAppMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HelmAppMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class HTTPServiceProxyCreateResponsePayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dns_url': 'str',
        'expires_at': 'datetime',
        'id': 'str',
        'password': 'str',
        'url': 'str',
        'username': 'str'
    }

    attribute_map = {
        'dns_url': 'dnsURL',
        'expires_at': 'expiresAt',
        'id': 'id',
        'password': 'password',
        'url': 'url',
        'username': 'username'
    }

    def __init__(self, dns_url=None, expires_at=None, id=None, password=None, url=None, username=None):  # noqa: E501
        """HTTPServiceProxyCreateResponsePayload - a model defined in Swagger"""  # noqa: E501
        self._dns_url = None
        self._expires_at = None
        self._id = None
        self._password = None
        self._url = None
        self._username = None
        self.discriminator = None
        self.dns_url = dns_url
        self.expires_at = expires_at
        self.id = id
        if password is not None:
            self.password = password
        self.url = url
        if username is not None:
            self.username = username

    @property
    def dns_url(self):
        """Gets the dns_url of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501

        DNS URL of the service proxy endpoint Valid only if setupDNS is set to true when creating the service proxy  # noqa: E501

        :return: The dns_url of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :rtype: str
        """
        return self._dns_url

    @dns_url.setter
    def dns_url(self, dns_url):
        """Sets the dns_url of this HTTPServiceProxyCreateResponsePayload.

        DNS URL of the service proxy endpoint Valid only if setupDNS is set to true when creating the service proxy  # noqa: E501

        :param dns_url: The dns_url of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :type: str
        """
        if dns_url is None:
            raise ValueError("Invalid value for `dns_url`, must not be `None`")  # noqa: E501

        self._dns_url = dns_url

    @property
    def expires_at(self):
        """Gets the expires_at of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501

        Expires at timestamp  # noqa: E501

        :return: The expires_at of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this HTTPServiceProxyCreateResponsePayload.

        Expires at timestamp  # noqa: E501

        :param expires_at: The expires_at of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :type: datetime
        """
        if expires_at is None:
            raise ValueError("Invalid value for `expires_at`, must not be `None`")  # noqa: E501

        self._expires_at = expires_at

    @property
    def id(self):
        """Gets the id of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501

        ID of the entity  # noqa: E501

        :return: The id of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HTTPServiceProxyCreateResponsePayload.

        ID of the entity  # noqa: E501

        :param id: The id of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def password(self):
        """Gets the password of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501

        Password to login to the service when setupBasicAuth=true.  # noqa: E501

        :return: The password of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this HTTPServiceProxyCreateResponsePayload.

        Password to login to the service when setupBasicAuth=true.  # noqa: E501

        :param password: The password of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def url(self):
        """Gets the url of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501

        URL of the service proxy endpoint  # noqa: E501

        :return: The url of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this HTTPServiceProxyCreateResponsePayload.

        URL of the service proxy endpoint  # noqa: E501

        :param url: The url of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def username(self):
        """Gets the username of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501

        Username to login to the service when setupBasicAuth=true.  # noqa: E501

        :return: The username of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this HTTPServiceProxyCreateResponsePayload.

        Username to login to the service when setupBasicAuth=true.  # noqa: E501

        :param username: The username of this HTTPServiceProxyCreateResponsePayload.  # noqa: E501
        :type: str
        """

        self._username = username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HTTPServiceProxyCreateResponsePayload, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HTTPServiceProxyCreateResponsePayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class NotificationTopics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    REPORTEDGE = "reportEdge"
    ONDELETEEDGE = "onDeleteEdge"
    ONUPDATEEDGE = "onUpdateEdge"
    REPORTEDGECLUSTER = "reportEdgeCluster"
    ONUPDATEEDGECLUSTER = "onUpdateEdgeCluster"
    ONDELETEEDGECLUSTER = "onDeleteEdgeCluster"
    REPORTSENSORS = "reportSensors"
    REPORTEDGEINFO = "reportEdgeInfo"
    APPLICATION_STATUS = "application-status"
    ONCREATEAPPLICATION = "onCreateApplication"
    ONDELETEAPPLICATION = "onDeleteApplication"
    ONUPDATEAPPLICATION = "onUpdateApplication"
    ONGETAPPLICATIONCONTAINERS = "onGetApplicationContainers"
    ONCREATECATEGORY = "onCreateCategory"
    ONDELETECATEGORY = "onDeleteCategory"
    ONUPDATECATEGORY = "onUpdateCategory"
    ONCREATEDATASOURCE = "onCreateDataSource"
    ONDELETEDATASOURCE = "onDeleteDataSource"
    ONUPDATEDATASOURCE = "onUpdateDataSource"
    ONCREATEDOCKERPROFILE = "onCreateDockerProfile"
    ONDELETEDOCKERPROFILE = "onDeleteDockerProfile"
    ONUPDATEDOCKERPROFILE = "onUpdateDockerProfile"
    ONCREATESCRIPT = "onCreateScript"
    ONDELETESCRIPT = "onDeleteScript"
    ONUPDATESCRIPT = "onUpdateScript"
    ONCREATESCRIPTRUNTIME = "onCreateScriptRuntime"
    ONDELETESCRIPTRUNTIME = "onDeleteScriptRuntime"
    ONUPDATESCRIPTRUNTIME = "onUpdateScriptRuntime"
    ONCREATEDATASTREAM = "onCreateDataStream"
    ONDELETEDATASTREAM = "onDeleteDataStream"
    ONUPDATEDATASTREAM = "onUpdateDataStream"
    ONGETDATAPIPELINECONTAINERS = "onGetDataPipelineContainers"
    ONCREATECLOUDCREDS = "onCreateCloudCreds"
    ONDELETECLOUDCREDS = "onDeleteCloudCreds"
    ONUPDATECLOUDCREDS = "onUpdateCloudCreds"
    ONCREATEPROJECT = "onCreateProject"
    ONDELETEPROJECT = "onDeleteProject"
    ONUPDATEPROJECT = "onUpdateProject"
    ONCREATEMLMODEL = "onCreateMLModel"
    ONDELETEMLMODEL = "onDeleteMLModel"
    ONUPDATEMLMODEL = "onUpdateMLModel"
    LOGUPLOAD = "logUpload"
    LOGSTREAM = "logStream"
    LOGUPLOADCOMPLETE = "logUploadComplete"
    EXECUTEEDGEUPGRADE = "executeEdgeUpgrade"
    SETUPSSHTUNNELING = "setupSSHTunneling"
    TEARDOWNSSHTUNNELING = "teardownSSHTunneling"
    ONCREATEPROJECTSERVICE = "onCreateProjectService"
    ONDELETEPROJECTSERVICE = "onDeleteProjectService"
    ONUPDATEPROJECTSERVICE = "onUpdateProjectService"
    ONCREATELOGCOLLECTOR = "onCreateLogCollector"
    ONDELETELOGCOLLECTOR = "onDeleteLogCollector"
    ONUPDATELOGCOLLECTOR = "onUpdateLogCollector"
    ONCREATESOFTWAREUPDATE = "onCreateSoftwareUpdate"
    ONUPDATESOFTWAREUPDATE = "onUpdateSoftwareUpdate"
    ONCREATESERVICEINSTANCE = "onCreateServiceInstance"
    ONUPDATESERVICEINSTANCE = "onUpdateServiceInstance"
    ONDELETESERVICEINSTANCE = "onDeleteServiceInstance"
    ONCREATESERVICEBINDING = "onCreateServiceBinding"
    ONDELETESERVICEBINDING = "onDeleteServiceBinding"
    ONCREATECONNECTORINSTANCE = "onCreateConnectorInstance"
    ONUPDATECONNECTORINSTANCE = "onUpdateConnectorInstance"
    ONDELETECONNECTORINSTANCE = "onDeleteConnectorInstance"
    HTTPPROXY = "httpProxy"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """NotificationTopics - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationTopics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationTopics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.sample_stream import SampleStream  # noqa: F401,E501


class Chart(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chart_type': 'str',
        'error': 'str',
        'max': 'int',
        'metrics': 'list[SampleStream]',
        'min': 'int',
        'name': 'str',
        'spans': 'int',
        'start_collapsed': 'bool',
        'unit': 'str'
    }

    attribute_map = {
        'chart_type': 'chartType',
        'error': 'error',
        'max': 'max',
        'metrics': 'metrics',
        'min': 'min',
        'name': 'name',
        'spans': 'spans',
        'start_collapsed': 'startCollapsed',
        'unit': 'unit'
    }

    def __init__(self, chart_type=None, error=None, max=None, metrics=None, min=None, name=None, spans=None, start_collapsed=None, unit=None):  # noqa: E501
        """Chart - a model defined in Swagger"""  # noqa: E501
        self._chart_type = None
        self._error = None
        self._max = None
        self._metrics = None
        self._min = None
        self._name = None
        self._spans = None
        self._start_collapsed = None
        self._unit = None
        self.discriminator = None
        if chart_type is not None:
            self.chart_type = chart_type
        if error is not None:
            self.error = error
        if max is not None:
            self.max = max
        if metrics is not None:
            self.metrics = metrics
        if min is not None:
            self.min = min
        if name is not None:
            self.name = name
        if spans is not None:
            self.spans = spans
        if start_collapsed is not None:
            self.start_collapsed = start_collapsed
        if unit is not None:
            self.unit = unit

    @property
    def chart_type(self):
        """Gets the chart_type of this Chart.  # noqa: E501


        :return: The chart_type of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._chart_type

    @chart_type.setter
    def chart_type(self, chart_type):
        """Sets the chart_type of this Chart.


        :param chart_type: The chart_type of this Chart.  # noqa: E501
        :type: str
        """

        self._chart_type = chart_type

    @property
    def error(self):
        """Gets the error of this Chart.  # noqa: E501


        :return: The error of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this Chart.


        :param error: The error of this Chart.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def max(self):
        """Gets the max of this Chart.  # noqa: E501


        :return: The max of this Chart.  # noqa: E501
        :rtype: int
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this Chart.


        :param max: The max of this Chart.  # noqa: E501
        :type: int
        """

        self._max = max

    @property
    def metrics(self):
        """Gets the metrics of this Chart.  # noqa: E501


        :return: The metrics of this Chart.  # noqa: E501
        :rtype: list[SampleStream]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this Chart.


        :param metrics: The metrics of this Chart.  # noqa: E501
        :type: list[SampleStream]
        """

        self._metrics = metrics

    @property
    def min(self):
        """Gets the min of this Chart.  # noqa: E501


        :return: The min of this Chart.  # noqa: E501
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this Chart.


        :param min: The min of this Chart.  # noqa: E501
        :type: int
        """

        self._min = min

    @property
    def name(self):
        """Gets the name of this Chart.  # noqa: E501


        :return: The name of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Chart.


        :param name: The name of this Chart.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def spans(self):
        """Gets the spans of this Chart.  # noqa: E501


        :return: The spans of this Chart.  # noqa: E501
        :rtype: int
        """
        return self._spans

    @spans.setter
    def spans(self, spans):
        """Sets the spans of this Chart.


        :param spans: The spans of this Chart.  # noqa: E501
        :type: int
        """

        self._spans = spans

    @property
    def start_collapsed(self):
        """Gets the start_collapsed of this Chart.  # noqa: E501


        :return: The start_collapsed of this Chart.  # noqa: E501
        :rtype: bool
        """
        return self._start_collapsed

    @start_collapsed.setter
    def start_collapsed(self, start_collapsed):
        """Sets the start_collapsed of this Chart.


        :param start_collapsed: The start_collapsed of this Chart.  # noqa: E501
        :type: bool
        """

        self._start_collapsed = start_collapsed

    @property
    def unit(self):
        """Gets the unit of this Chart.  # noqa: E501


        :return: The unit of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this Chart.


        :param unit: The unit of this Chart.  # noqa: E501
        :type: str
        """

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Chart, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Chart):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
